==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/EventListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EventListBuilder extends io.fabric8.kubernetes.api.model.EventListFluentImpl<io.fabric8.kubernetes.api.model.EventListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.EventList,io.fabric8.kubernetes.api.model.EventListBuilder>{
  public EventListBuilder() {
    this(false);
  }
  public EventListBuilder(java.lang.Boolean validationEnabled) {
    this(new EventList(), validationEnabled);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent) {
    this(fluent, false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EventList(), validationEnabled);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,io.fabric8.kubernetes.api.model.EventList instance) {
    this(fluent, instance, false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,io.fabric8.kubernetes.api.model.EventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventList instance) {
    this(instance,false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.EventListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.EventList build() {
    EventList buildable = new EventList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventListBuilder that = (EventListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/EventListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EventListBuilder extends io.fabric8.kubernetes.api.model.EventListFluentImpl<io.fabric8.kubernetes.api.model.EventListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.EventList,io.fabric8.kubernetes.api.model.EventListBuilder>{
  public EventListBuilder() {
    this(false);
  }
  public EventListBuilder(java.lang.Boolean validationEnabled) {
    this(new EventList(), validationEnabled);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent) {
    this(fluent, false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EventList(), validationEnabled);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,io.fabric8.kubernetes.api.model.EventList instance) {
    this(fluent, instance, false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventListFluent<?> fluent,io.fabric8.kubernetes.api.model.EventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventList instance) {
    this(instance,false);
  }
  public EventListBuilder(io.fabric8.kubernetes.api.model.EventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.EventListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.EventList build() {
    EventList buildable = new EventList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventListBuilder that = (EventListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
